function [go,ss_height,ss_period]=check_ss_period(tout,yout,hopper)
% check_ss_period takes the time history and looks for periodocity over the
% last 10 activation periods.  If it finds a steady state, it returns the
% maximum height over the period, the number of activation periods that
% define the steady state period (for period-1,2,3,... orbits) and a flag
% to stop the simulation.
go=1;
ss_height=0;
ss_period=0;

if max(tout)/hopper.period > 10     % Don't bother if you haven't done ten hops yet.
    ind1 = min(find(tout>max(tout)-hopper.period));
    ind2 = size(yout,1);
    [temp,max_ind]=max(yout(ind1:ind2,3));
    max_ind=max_ind+ind1-1;
    max_height_state = yout(max_ind,:);
    max_height_time = tout(max_ind);
    pd_count=1;
    match=0;
    while (pd_count <= 20) & (pd_count < max(tout)/hopper.period)
        next_ind = min(find(tout>=max_height_time-pd_count*hopper.period));
        %state_error = norm([abs(max_height_state(1)-yout(next_ind,1)), abs(max_height_state(3)-yout(next_ind,3))]);
        state_error = abs(max_height_state(3)-yout(next_ind,3))/max_height_state(3);  % In percent of max_height
        % only looking at positions because velocities are very sensitive
        % around the maximum height...
        t_curr = tout(next_ind);
        if state_error < hopper.ss_tolerance
            match=pd_count;
            pd_count = 21;
        else
            pd_count = pd_count+1;
        end
    end  %either have a match or don't
    if match>0  % have a match, so check previous five periods
        period_check = match;
        pd_count=1;
        while pd_count<=5
            next_ind = min(find(tout>=max_height_time-pd_count*match*hopper.period));
            %state_error = norm([abs(max_height_state(1)-yout(next_ind,1)), abs(max_height_state(3)-yout(next_ind,3))]);
            state_error = abs(max_height_state(3)-yout(next_ind,3))/max_height_state(3); % In percent of max_height
            t_curr = tout(next_ind);
            if state_error < hopper.ss_tolerance
                if pd_count >= 5
                    go=0; %have 3 matches
                    %ss_height = max(yout(next_ind:ind2,1));
                    ss_height = max(yout(next_ind:ind2,3));  % Changed to be foot height instead of body height
                    ss_period = match;
                end
            else
                pd_count = 10;
            end
            pd_count = pd_count+1;
        end
    end
end

end

